@@ -1,7 +1,6 @@
-
 // interface.c
 // LiVES
-// (c) G. Finch 2003 - 2015 <salsaman@gmail.com>
+// (c) G. Finch 2003 - 2016 <salsaman@gmail.com>
 // Released under the GNU GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -93,13 +92,14 @@ void widget_add_preview(LiVESWidget *widget, LiVESBox *for_preview, LiVESBox *fo
   LiVESWidget *preview_button=NULL;
   LiVESWidget *fs_label;
 
-  mainw->fs_playframe = lives_frame_new(NULL);
-  mainw->fs_playalign = lives_alignment_new(0.,0.,1.,1.);
-  mainw->fs_playarea = lives_event_box_new();
-
-  lives_widget_object_set_data(LIVES_WIDGET_OBJECT(mainw->fs_playarea),"pixbuf",NULL);
 
   if (preview_type==LIVES_PREVIEW_TYPE_VIDEO_AUDIO||preview_type==LIVES_PREVIEW_TYPE_RANGE) {
+    mainw->fs_playframe = lives_frame_new(NULL);
+    mainw->fs_playalign = lives_alignment_new(0.,0.,1.,1.);
+    mainw->fs_playarea = lives_event_box_new();
+
+    lives_widget_object_set_data(LIVES_WIDGET_OBJECT(mainw->fs_playarea),"pixbuf",NULL);
+
     lives_container_set_border_width(LIVES_CONTAINER(mainw->fs_playframe), widget_opts.border_width);
 
     widget_opts.justify=LIVES_JUSTIFY_RIGHT;
@@ -118,7 +118,8 @@ void widget_add_preview(LiVESWidget *widget, LiVESBox *for_preview, LiVESBox *fo
     lives_widget_set_bg_color(mainw->fs_playframe, LIVES_WIDGET_STATE_NORMAL, &palette->black);
     lives_widget_set_bg_color(mainw->fs_playalign, LIVES_WIDGET_STATE_NORMAL, &palette->black);
 
-  }
+  } else mainw->fs_playframe = mainw->fs_playalign = mainw->fs_playarea = NULL; // AUDIO_ONLY
+
 
 
   if (preview_type==LIVES_PREVIEW_TYPE_VIDEO_AUDIO) {
@@ -151,6 +152,8 @@ void widget_add_preview(LiVESWidget *widget, LiVESBox *for_preview, LiVESBox *fo
 }
 
 
+
+
 xprocess *create_processing(const char *text) {
 
   LiVESWidget *dialog_vbox;
@@ -225,6 +228,7 @@ xprocess *create_processing(const char *text) {
     widget_opts.apply_theme=FALSE;
     procw->scrolledwindow = lives_standard_scrolled_window_new(ENC_DETAILS_WIN_H, ENC_DETAILS_WIN_V, LIVES_WIDGET(mainw->optextview));
     lives_widget_set_size_request(procw->scrolledwindow, ENC_DETAILS_WIN_H, ENC_DETAILS_WIN_V);
+
     widget_opts.apply_theme=woat;
 
     details_arrow=lives_standard_expander_new(_("Show Details"),FALSE,LIVES_BOX(vbox3),procw->scrolledwindow);
@@ -2085,6 +2089,10 @@ static void chooser_check_dir(LiVESFileChooser *chooser, livespointer user_data)
 }
 
 
+static void chooser_response(LiVESWidget *widget, int response, livespointer udata) {
+  mainw->fc_buttonresponse=response;
+}
+
 
 
 char *choose_file(const char *dir, const char *fname, char **const filt, LiVESFileChooserAction act,
@@ -2139,11 +2147,6 @@ char *choose_file(const char *dir, const char *fname, char **const filt, LiVESFi
   gtk_file_chooser_set_local_only(LIVES_FILE_CHOOSER(chooser),TRUE);
 
 
-  if (mainw->is_ready && palette->style&STYLE_1) {
-    lives_widget_set_bg_color(chooser, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
-    set_child_colour(chooser,FALSE);
-  }
-
   if (dir!=NULL) {
     gtk_file_chooser_set_current_folder(LIVES_FILE_CHOOSER(chooser),dir);
     gtk_file_chooser_add_shortcut_folder(LIVES_FILE_CHOOSER(chooser),dir,NULL);
@@ -2168,6 +2171,23 @@ char *choose_file(const char *dir, const char *fname, char **const filt, LiVESFi
 
   if (extra_widget!=NULL && extra_widget!=mainw->LiVES) gtk_file_chooser_set_extra_widget(LIVES_FILE_CHOOSER(chooser),extra_widget);
 
+  if (palette->style&STYLE_1) {
+    GtkWidget *parent=lives_widget_get_parent(extra_widget);
+
+    while (parent!=NULL) {
+      lives_widget_set_fg_color(parent, LIVES_WIDGET_STATE_NORMAL, &palette->normal_fore);
+      lives_widget_set_bg_color(parent, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
+      parent=lives_widget_get_parent(parent);
+    }
+
+  }
+
+  if (mainw->is_ready && palette->style&STYLE_1) {
+    lives_widget_set_bg_color(chooser, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
+    set_child_colour(chooser,FALSE);
+  }
+
+
 #endif
 
 #ifdef GUI_QT
@@ -2249,6 +2269,10 @@ char *choose_file(const char *dir, const char *fname, char **const filt, LiVESFi
 
   memset(last_good_folder,0,1);
 
+  // set this so we know when button is pressed, even if waiting for preview to finish
+  mainw->fc_buttonresponse=LIVES_RESPONSE_NONE;
+  lives_signal_connect(chooser, LIVES_WIDGET_RESPONSE_SIGNAL, LIVES_GUI_CALLBACK(chooser_response), NULL);
+  
   if (extra_widget==mainw->LiVES) {
     return (char *)chooser; // kludge to allow custom adding of extra widgets
   }
@@ -2567,8 +2591,57 @@ LiVESWidget *create_cleardisk_advanced_dialog(void) {
 }
 
 
+
+#ifdef GTK_TEXT_VIEW_DRAW_BUG
+
+static boolean exposetview(LiVESWidget *widget, lives_painter_t *cr, livespointer user_data) {
+  LiVESWidgetColor fgcol,bgcol;
+  lives_colRGBA32_t fg,bg;
+  LingoLayout *layout;
+  lives_painter_surface_t *surface;
+
+  char *text=lives_text_view_get_text(LIVES_TEXT_VIEW(widget));
+
+  surface=lives_painter_get_target(cr);
+  lives_painter_surface_flush(surface);
+
+  lives_widget_get_fg_state_color(widget,lives_widget_get_state(widget),&fgcol);
+  lives_widget_get_bg_state_color(widget,lives_widget_get_state(widget),&bgcol);
+
+  widget_rgba_to_lives_rgba(&fg,&fgcol);
+  widget_rgba_to_lives_rgba(&bg,&bgcol);
+
+  // TODO - can we clip cr to visible area ?
+
+  layout=render_text_to_cr(widget,cr,text,"",0.0,
+                           LIVES_TEXT_MODE_FOREGROUND_AND_BACKGROUND,&fg,&bg,FALSE,FALSE,0.,0.,
+                           lives_widget_get_allocation_width(widget),lives_widget_get_allocation_height(widget));
+
+  lives_free(text);
+
+  lingo_painter_show_layout(cr, layout);
+
+  if (layout) lives_object_unref(layout);
+
+  lives_painter_fill(cr);
+
+  return TRUE;
+}
+
+
+#endif
+
+
+
+
+
 LiVESTextView *create_output_textview(void) {
   LiVESWidget *textview=lives_text_view_new();
+
+#ifdef GTK_TEXT_VIEW_DRAW_BUG
+  g_signal_connect(textview,"draw",G_CALLBACK(exposetview),NULL);
+#endif
+
   lives_text_view_set_editable(LIVES_TEXT_VIEW(textview), FALSE);
 
   if (palette->style&STYLE_1) {
