@@ -1,6 +1,6 @@
 // main.h
 // LiVES
-// (c) G. Finch (salsaman@gmail.com) 2003 - 2015
+// (c) G. Finch (salsaman@gmail.com) 2003 - 2016
 // see file ../COPYING for full licensing details
 
 /*  This program is free software; you can redistribute it and/or modify
@@ -277,6 +277,20 @@ typedef int lives_pgid_t;
 
 uint64_t lives_random(void);
 
+typedef struct {
+  uint16_t red;
+  uint16_t green;
+  uint16_t blue;
+} lives_colRGB24_t;
+
+typedef struct {
+  uint16_t red;
+  uint16_t green;
+  uint16_t blue;
+  uint16_t alpha;
+} lives_colRGBA32_t;
+
+
 #include "widget-helper.h"
 
 typedef  void *(*fn_ptr)(void *ptr);
@@ -457,20 +471,6 @@ typedef enum {
 #define AFORM_UNKNOWN 65536
 
 
-typedef struct {
-  uint16_t red;
-  uint16_t green;
-  uint16_t blue;
-} lives_colRGB24_t;
-
-typedef struct {
-  uint16_t red;
-  uint16_t green;
-  uint16_t blue;
-  uint16_t alpha;
-} lives_colRGBA32_t;
-
-
 typedef enum {
   LIVES_INTERLACE_NONE=0,
   LIVES_INTERLACE_BOTTOM_FIRST=1,
@@ -962,7 +962,7 @@ void do_cd_error_dialog(void);
 boolean process_one(boolean visible);
 void do_threaded_dialog(char *translated_text, boolean has_cancel);
 void end_threaded_dialog(void);
-void threaded_dialog_spin(void);
+void threaded_dialog_spin(double fraction);
 void response_ok(LiVESButton *button, livespointer user_data);
 void pump_io_chan(LiVESIOChannel *iochan);
 
